@@ -14,6 +14,16 @@ In order to plug Django-flash to your project, open your project's
 
 Doing this your view templates will be able to access the flash scope
 contents using the ``flash`` context variable.
+
+.. warning::
+
+   Your views should use the :class:`RequestContext` class to render the view
+   templates, otherwise the ``flash`` variable (along with *all* other
+   variables provided by other context processors) won't be available to you.
+   Please read the
+   `Django documentation <http://docs.djangoproject.com/en/dev/ref/templates/api/>`_
+   for further instructions.
+
 """
 
 CONTEXT_VAR = 'flash'
